==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/emulator/dialogs_nl.lua <==

dialogId("zx-m-pametnici", "font_small", "So this is a level for real connoisseurs.")
dialogStr("Dit is een veld voor de echte kenner.")


dialogId("zx-v-osmibit", "font_big", "Yeah, I feel like I can feel the eight bit wind of history.")
dialogStr("Ja, ik voel gewoon de acht-bitse wind.")


dialogId("zx-m-pixel", "font_small", "Can you see that pixel graphic all around us? I must confess I feel nostalgic.")
dialogStr("Zie je al die antieke grafische weergave om ons heen? Ik voel me nostalgisch.")


dialogId("zx-v-hry", "font_big", "This is an opportunity to play the merry old games of ZX Spectrum.")
dialogStr("Dit is een goede kans om de oude spelletjes van de ZX-Spectrum te spelen.")


dialogId("zx-m-premyslis", "font_small", "What are you thinking about now?")
dialogStr("Waar denk je nu aan?")


dialogId("zx-v-pamet", "font_big", "Well, I just realized that the animations of us two alone would fill up the RAM of a ZX Spectrum.")
dialogStr("Nouja, ik realiseer me net dat de animaties van ons tweeën alleen al al het werkgeheugen van een ZX Spectrum zouden opeten.")


dialogId("zx-v-otazka", "font_big", "Do you know that your question alone in WAV format would overfill the RAM of ZX Spectrum? And imagine how many such sounds are in this game.")
dialogStr("Weet je dat jouw vraag alleen al in WAV formaat het werkgeheugen zouden opmaken? En stel je eens voor hoeveel van dat soort geluiden er in dit spel zitten.")


dialogId("zx-m-necodosebe", "font_small", "But still, these games had something to them, didn`t they?")
dialogStr("Maar toch, deze spelletjes hadden wel iets, vind je niet?")


dialogId("zx-m-knight", "font_small", "Can you see that Knight Lorer?")
dialogStr("Zie je die Knight Lorer?")


dialogId("zx-v-manicminer", "font_big", "And that must be the Manic Miner.")
dialogStr("En dat is de Manic Miner.")


dialogId("zx-m-jetpack", "font_small", "I really didn`t know I`d ever be putting the Jetpack together again.")
dialogStr("Ik had niet gedacht dat ik ooit nog dit Jetpack weer inelkaar zou zetten.")


dialogId("zx-v-roboti", "font_big", "This line of robots looks familiar.")
dialogStr("Deze rij robotjes ziet er bekend uit.")


dialogId("zx-m-highway", "font_small", "Oh sure, they are from the Highway Encounter.")
dialogStr("Ja, natuurlijk, die komen uit Highway Encounter.")


dialogId("zx-v-nahravani", "font_big", "I wonder what is loading right now.")
dialogStr("Ik vraag me af wat er nu geladen wordt.")


dialogId("zx-m-ocel", "font_small", "The single biggest advantage of this room is that it contains no steel.")
dialogStr("Het grootste voordeel van dit veld is dat er geen staal is.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/emulator/dialogs_nl.lua <==

dialogId("zx-m-pametnici", "font_small", "So this is a level for real connoisseurs.")
dialogStr("Dit is een veld voor de echte kenner.")


dialogId("zx-v-osmibit", "font_big", "Yeah, I feel like I can feel the eight bit wind of history.")
dialogStr("Ja, ik voel gewoon de acht-bitse wind.")


dialogId("zx-m-pixel", "font_small", "Can you see that pixel graphic all around us? I must confess I feel nostalgic.")
dialogStr("Zie je al die antieke grafische weergave om ons heen? Ik voel de nostalgie opkomen.")


dialogId("zx-v-hry", "font_big", "This is an opportunity to play the merry old games of ZX Spectrum.")
dialogStr("Dit is een goede kans om de oude spelletjes van de ZX-Spectrum te spelen.")


dialogId("zx-m-premyslis", "font_small", "What are you thinking about now?")
dialogStr("Waar denk je nu aan?")


dialogId("zx-v-pamet", "font_big", "Well, I just realized that the animations of us two alone would fill up the RAM of a ZX Spectrum.")
dialogStr("Nouja, ik realiseer me net dat de animaties van ons tweeën alleen al al het werkgeheugen van een ZX Spectrum zouden opeten.")


dialogId("zx-v-otazka", "font_big", "Do you know that your question alone in WAV format would overfill the RAM of ZX Spectrum? And imagine how many such sounds are in this game.")
dialogStr("Weet je dat jouw vraag alleen al in wav formaat het werkgeheugen zou opmaken? En stel je eens voor hoeveel van dat soort geluiden er in dit spel zitten.")


dialogId("zx-m-necodosebe", "font_small", "But still, these games had something to them, didn’t they?")
dialogStr("Maar toch, deze spelletjes hadden wel iets, vind je niet?")


dialogId("zx-m-knight", "font_small", "Can you see that Knight Lorer?")
dialogStr("Zie je die Knight Lorer?")


dialogId("zx-v-manicminer", "font_big", "And that must be the Manic Miner.")
dialogStr("En dat is de Manic Miner.")


dialogId("zx-m-jetpack", "font_small", "I really didn’t know I’d ever be putting the Jetpack together again.")
dialogStr("Ik had niet gedacht dat ik ooit nog dit Jetpack weer inelkaar zou zetten.")


dialogId("zx-v-roboti", "font_big", "This line of robots looks familiar.")
dialogStr("Deze rij robotjes ziet er bekend uit.")


dialogId("zx-m-highway", "font_small", "Oh sure, they are from the Highway Encounter.")
dialogStr("Ja, natuurlijk, die komen uit Highway Encounter.")


dialogId("zx-v-nahravani", "font_big", "I wonder what is loading right now.")
dialogStr("Ik vraag me af wat er nu geladen wordt.")


dialogId("zx-m-ocel", "font_small", "The single biggest advantage of this room is that it contains no steel.")
dialogStr("Het grootste voordeel van dit veld is dat er geen staal is.")
